@@ -1069,6 +1069,8 @@ The result file is not found in working dir {wd}:
 
 This usually means that the evaluator did not finish and some times that there was an import error.
 Check the evaluator log to see what happened."""
+            l = "\n".join("-" + f for f in list_all_files(wd))
+            msg += f"\n\nList of all files:\n\n {l}"
             elogger.error(msg)
             status = ChallengesConstants.STATUS_JOB_ERROR
             cr = ChallengeResults(status, msg, scores={})
@@ -1096,6 +1098,10 @@ Check the evaluator log to see what happened."""
     return cr
 
 
+def list_all_files(wd: str) -> List[str]:
+    return [os.path.join(dp, f) for dp, dn, fn in os.walk(wd) for f in fn]
+
+
 def prepare_dir(wd, aws_config, steps2artefacts, use_ipfs: bool):
     if not os.path.exists(wd):
         os.makedirs(wd)
